<?php

/**
 * @file
 * Advanced catalog administration menu items.
 */

/**
 * Settings forms for using a product grid instead of a table in the catalog.
 *
 * @ingroup forms
 */
function uc_advanced_catalog_settings_form() {
  $form = array();
  $view_url = 'admin/build/views/edit/advanced_catalog';

  $form['uc_advanced_catalog'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display products in the catalog using advanced catalog.'),
    '#summary callback' => 'summarize_checkbox',
    '#summary arguments' => array(
      t('Products are displayed using advanced catalog.'),
      t('Products are not displayed using advanced catalog.'),
    ),
    '#default_value' => variable_get('uc_advanced_catalog', FALSE),
    '#description' => t('If unchecked, the default table or grid display will be used and the settings on this form will be ignored.'),
  );
  $form['uc_advanced_catalog_pager'] = array(
    '#type' => 'select',
    '#title' => t('Pager and filter position'),
    '#options' => array(
      'top' => t('Top'),
      'bottom' => t('Bottom'),
      'top-bottom' => t('Top and Bottom'),
    ),
    '#description' => t('Select where the pager and filter will be display on catalog.'),
    '#default_value' => variable_get('uc_advanced_catalog_pager', 'top-bottom'),
  );
  $form['uc_advanced_catalog_sticky'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display 2 last sticky products in the catalog heading.'),
    '#summary callback' => 'summarize_checkbox',
    '#summary arguments' => array(
      t('2 sticky products are displayed in the catalog heading.'),
      t('Sticky products are not displayed in the catalog heading.'),
    ),
    '#default_value' => variable_get('uc_advanced_catalog_sticky', FALSE),
    '#description' => t('If checked, 2 last (published date) sticky products of current taxonomy will be shown before the catalog list.') .'<br/>'.
      t('You can manually add sticky bloc on catalog page you want by using block admin with page limit feature.') .'<br/>'.
      t('<a href="!url">You can edit this view here</a>.', array('!url' => url($view_url .'_sticky', array('fragment' => 'views-tab-block_1')))),
  );
  $form['displayed_filters'] = array(
    '#type' => 'fieldset',
    '#title' => t('Displayed filters'),
    '#description' => t('The checked fields will be included in your catalog filter area.') .'<br/>'.
    t('Select wich default view will be used when available, even if filter is not allowed.') .'<br/>'.
    t('You can reorder filter, first one will be on the left side.'),
  );

  // Sortable table
  $form['displayed_filters']['list']['#tree'] = TRUE;
  $form['displayed_filters']['list']['#theme'] = 'uc_advanced_catalog_settings_list_form';

  // hook_catalog_filters
  $filters = module_invoke_all('catalog_filters');
  foreach ($filters AS $values) {
    $filter[] = _uc_advanced_catalog_filter_edit($values);
  }
  // reorder filter by weight
  usort($filter, '_filter_compare');
  $form['displayed_filters']['list'] += $filter;

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );
  $form['reset'] = array(
    '#type' => 'submit',
    '#value' => t('Reset to defaults'),
  );
  return $form;
}

function uc_advanced_catalog_settings_form_submit($form, &$form_state) {
  // global save
  if ($form_state['values']['op'] == t('Save configuration')) {
    // disable grid display
    if ($form_state['values']['uc_advanced_catalog'] == 1) {
      variable_set('uc_catalog_grid_display', 0);
    }
    foreach (element_children($form_state['values']) as $key) {
      if (drupal_substr($key, 0, 11) == 'uc_advanced') {
        variable_set($key, $form_state['values'][$key]);
      }
    }
    foreach (element_children($form_state['values']['list']) as $key) {
      // weight
      $name = key($form_state['values']['list'][$key]['title']);
      variable_set($name . '_weight', $form_state['values']['list'][$key]['sort']);
      // registered filters
      if ($form_state['values']['list'][$key]['title'][$name] == 1) {
        $registered[] = $form_state['values']['list'][$key]['name'];
      }
      // other values
      foreach ($form_state['values']['list'][$key] AS $v) {
        if (is_array($v)) {
          foreach ($v as $variable => $value) {
            variable_set($variable, $value);
          }
        }
      }
    }
    drupal_set_message(t('Advanced catalog settings saved.'));
    // save only registered filters for _uc_advanced_catalog_default()
    variable_set('uc_advanced_catalog_registered', $registered);
  }
  // reset
  if ($form_state['values']['op'] == t('Reset to defaults')) {
    if (db_query("DELETE FROM {variable} WHERE name LIKE 'uc_advanced_catalog%'")) {
      unset($_SESSION['uc_advanced_catalog']);
      drupal_set_message(t('Advanced catalog values back to default.'));
      // not sure but don't find delete variable cache function...
      drupal_flush_all_caches();
    }
  }
}

/**
  * Theme the re-ordering form
  */
function theme_uc_advanced_catalog_settings_list_form($form) {
  drupal_add_tabledrag('advanced-catalog-sort', 'order', 'sibling', 'sort');
  $header = array('', t('Filters'), t('Default value'), t('Options'), '');
  $rows = array();
  foreach (element_children($form) as $key) {
    // Add class to group weight fields for drag and drop.
    $form[$key]['sort']['#attributes']['class'] = 'sort';
    $row = array();
    $row[] = drupal_render($form[$key]['name']);
    $row[] = drupal_render($form[$key]['title']);
    $row[] = drupal_render($form[$key]['default']);
    $row[] = drupal_render($form[$key]['options']);
    $row[] = drupal_render($form[$key]['sort']);
    $rows[$key] = array('data' => $row, 'class' => 'draggable');
  }
  // order by weight
  ksort($rows);
  $output = theme('table', $header, $rows, array('id' => 'advanced-catalog-sort'));
  $output .= drupal_render($form);
  return $output;
}

/**
 * Helper function for sorting rows on settings form
 * Code from sorting blocks on admin/build/block.
 *
 * Rows are sorted by weight, then by title.
 */
function _filter_compare($a, $b) {
  // Sort by weight.
  $weight = $a['sort']['#default_value'] - $b['sort']['#default_value'];
  if ($weight) {
    return $weight;
  }
  // Sort by title.
  return strcmp($a['title'], $b['title']);
}
